Learn R Programming

tourr (version 1.2.8)

basis_dep_init: Initial basis for dependence tour.

Description

First two variables are projected on first two axes.

Usage

basis_dep_init(n, d, pos)

Arguments

n

dimensionality of data

d

dimensionality of target projection

pos

a numeric vector describing which variables are mapped to which dimensions: 1 corresponds to first, 2 to second etc.