blank_plot: Set up a blank plot to display data projections

View source: R/util.r

blank_plotR Documentation

Set up a blank plot to display data projections

Description

Set up a blank plot to display data projections

Usage

blank_plot(...)

tourr documentation built on May 15, 2026, 9:06 a.m.