Toggle navigation
tourr
1.2.7
Reference
Articles
Introduction
Different types of tours
Edges
Labelling observations
Center a numeric vector by subtracting off its mean.
Source:
R/util.r
center.Rd
Center a numeric vector by subtracting off its mean.
center
(
x
)
Arguments
x
numeric vector
Contents