correct_orientation: check if the current and target bases are of the same...

View source: R/search-better.r

correct_orientationR Documentation

check if the current and target bases are of the same orientation

Description

check if the current and target bases are of the same orientation

Usage

correct_orientation(current, target)

tourr documentation built on May 15, 2026, 9:06 a.m.