The dependence tour combines a set of independent 1d tours to produce a nd tour. For the special case of 2d, this is known as a correlation tour. This tour corresponds to the multivariate method known as generalised canonical correlation, and is used to investigate dependence between groups of variables.
Details
Usually, you will not call this function directly, but will pass it to
a method that works with tour paths like animate,
save_history or render.
Examples
animate_xy(flea[, 1:3], dependence_tour(c(1, 2, 2)))
#> Converting input data to the required matrix format.
#> Using half_range 3.5
animate_xy(flea[, 1:4], dependence_tour(c(1, 2, 1, 2)))
#> Converting input data to the required matrix format.
#> Using half_range 3.7
animate_pcp(flea[, 1:6], dependence_tour(c(1, 2, 3, 2, 1, 3)))
#> Converting input data to the required matrix format.