Animate a nD tour path with Chernoff's faces. Can display up to 18 dimensions.
Usage
display_faces(...)
animate_faces(data, tour_path = grand_tour(3), ...)Arguments
- ...
other arguments passed on to
animate- data
matrix, or data frame containing numeric columns
- tour_path
tour path generator, defaults to 2d grand tour
Details
This function requires the aplpack package to draw the
Chernoff faces. See faces for more details.
See also
animate for options that apply to all animations
Examples
# The drawing code is fairly slow, so this animation works best with a
# limited number of cases
flea_s <- rescale(flea[,1:6])
animate_faces(flea_s[19:24, 1:6])
animate_faces(flea_s[19:24, 1:6], grand_tour(5))