find_platform: Find the platform Find the platform being used by the user

View source: R/util.r

find_platformR Documentation

Find the platform Find the platform being used by the user

Description

Find the platform Find the platform being used by the user

Usage

find_platform()

tourr documentation built on May 15, 2026, 9:06 a.m.