The local tour alternates between the starting position and a nearby random projection.
Details
Usually, you will not call this function directly, but will pass it to
a method that works with tour paths like animate,
save_history or render.
Examples
animate_xy(flea[, 1:3], local_tour(basis_init(3, 2)))
#> Converting input data to the required matrix format.
#> Using half_range 3.5
animate_xy(flea[, 1:3], local_tour(basis_init(3, 2), 0.2))
#> Converting input data to the required matrix format.
#> Using half_range 3.5
animate_xy(flea[, 1:3], local_tour(basis_random(3, 2), 0.2))
#> Converting input data to the required matrix format.
#> Using half_range 3.5