Search for a better projection near the current projection.
Source:R/search-better.r
search_better.RdSearch for a better projection near the current projection.
Usage
search_better(
current,
alpha = 0.5,
index,
tries,
max.tries = Inf,
...,
method = "linear",
cur_index = NA
)Arguments
- current
starting projection
- alpha
the angle used to search the target basis from the current basis
- index
index function
- tries
the counter of the outer loop of the opotimiser
- max.tries
maximum number of iteration before giving up
- ...
other arguments being passed into the
search_better()- method
whether the nearby bases are found by a linear/ geodesic formulation
- cur_index
the index value of the current basis
Examples
animate_xy(flea[, 1:6], guided_tour(holes(), search_f = search_better))
#> Converting input data to the required matrix format.
#> Target: 0.854, try: 1
#> Using half_range 4.4