Search for a better projection based on Poss, 1995
Arguments
- current
starting projection
- alpha
the angle used to search the target basis from the current basis
- index
index function
- tries
the counter of the outer loop of the opotimiser
- max.tries
maximum number of iteration before giving up
- cur_index
the index value of the current basis
- ...
other arguments being passed into the
search_better()