spline-loess: Spline/loess based index.

splines2dR Documentation

Spline/loess based index.

Description

Compares the variance in residuals of a fitted spline/loess model to the overall variance to find functional dependence in 2D projections of the data.

Usage

splines2d()

loess2d()

tourr documentation built on May 15, 2026, 9:06 a.m.