Implements geodesic interpolation and basis generation functions that allow you to create new tour methods from R.
Maintainer: Dianne Cook [email protected] (ORCID)
Authors:
Dianne Cook [email protected] (ORCID)
Hadley Wickham [email protected] (ORCID) [contributor]
Other contributors:
Nick Spyrison [email protected] (ORCID) [contributor]
Ursula Laa [email protected] (ORCID) [contributor]
H. Sherry Zhang [email protected] (ORCID) [contributor]
Stuart Lee [email protected] (ORCID) [contributor]
Useful links: