Learn R Programming

tourr (version 1.0.0)

weights_bincount_radial: Computes weights for the rescaling of radial bin counts.

Description

Computes weights for the rescaling of radial bin counts.

Usage

weights_bincount_radial(histo, p)

Arguments

p

number of variables

hsisto

input histogram (for bin definitions)