Skip to contents
tourr
1.2.7
Reference
Articles
Introduction to tourr
Edges in scatterplot displays
Changelog
Center a numeric vector by subtracting off its mean.
Source:
R/util.r
center.Rd
Center a numeric vector by subtracting off its mean.
Usage
center
(
x
)
Arguments
x
numeric vector