center: Center a numeric vector by subtracting off its mean.

View source: R/util.r

centerR Documentation

Center a numeric vector by subtracting off its mean.

Description

Center a numeric vector by subtracting off its mean.

Usage

center(x)

Arguments

x

numeric vector


tourr documentation built on May 15, 2026, 9:06 a.m.