- centr
if TRUE, centers projected data to (0,0). This pins the
center of data cloud and make it easier to focus on the changing shape
rather than position.
- axes
position of the axes: center, bottomleft or off
- half_range
half range to use when calculating limits of projected.
If not set, defaults to maximum distance from origin to each row of data.
- col
color to use for points, can be a vector or hexcolors or a factor. Defaults to "black".
- pch
shape of the point to be plotted. Defaults to 20.
- cex
size of the point to be plotted. Defaults to 1.
- edges
A two column integer matrix giving indices of ends of lines.
- edges.col
colour of edges to be plotted, Defaults to "black"
- edges.width
line width for edges, default 1
- group_by
variable to group by. Must have less than 25 unique values.
- plot_xgp
if TRUE, plots points from other groups in light grey
- palette
name of color palette for point colour, used by hcl.colors, default "Zissou 1"
- ...
other arguments passed on to animate and
display_groupxy
- data
matrix, or data frame containing numeric columns
- tour_path
tour path generator, defaults to 2d grand tour