Compares the variance in residuals of a fitted spline/loess model to the overall variance to find functional dependence in 2D projections of the data.
Compares the variance in residuals of a fitted spline/loess model to the overall variance to find functional dependence in 2D projections of the data.